@@ -41,7 +41,6 @@
  **********************************************************************/
 
 #include <R.h>
-/* #include <R_ext/BLAS.h> */
 #include "util.h"
 
 #define THRESH 200.0
@@ -702,17 +701,6 @@ void locate_xo(int n_ind, int n_mar, int type, int **Geno,
     } /* end loop over individuals */
 }
 
-/* multiply two matrices - I'm using dgemm from lapack here */
-/*
-  void matmult2(double *result, double *a, int nrowa,
-  int ncola, double *b, int ncolb)
-
-  {
-  double alpha=1.0, beta=1.0;
-  F77_CALL(dgemm)("N", "N", &nrowa, &ncolb, &ncola, &alpha, a, &nrowa,
-  b, &ncola, &beta, result, &nrowa);
-  }
-*/
 
 void matmult(double *result, double *a, int nrowa,
              int ncola, double *b, int ncolb)
